@@ -23,6 +23,7 @@
 #' @param suggestion.distance a value between 0 and 1 indicanting how conservative the
 #'   name suggestion algorithm should be. Values closer to 1 are very
 #'   conservative. Be very careful, lower values can give wrong suggestions.
+#' @param parse Parse names through the GBIF parser to remove authors?
 #' @details The returned data frame will contain a variable number of rows and 
 #'   columns depending on how the function was called. For instance, since there
 #'   might be more than one vernacular name for each taxon, some rows
@@ -40,7 +41,8 @@
 get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE, 
                       life.form = FALSE, habitat = FALSE, vernacular = FALSE, states = FALSE, 
                       establishment = FALSE, drop = c("authorship", "genus", "specific.epiteth", 
-                                                      "infra.epiteth", "name.status"), suggestion.distance = 0.9) 
+                                                      "infra.epiteth", "name.status"), 
+                      suggestion.distance = 0.9, parse = FALSE) 
 {
   taxa <- trim(taxa)
   taxa <- taxa[nzchar(taxa)]
@@ -56,6 +58,16 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
   for (taxon in taxa) {
     notes <- NULL
     index <- index + 1
+    if (parse) {
+      url <- "http://api.gbif.org/v1/parser/name"
+      request <- try(POST(url, body = list(taxon), encode = "json"))
+      if (inherits(request, "try-error")) {
+        warning("Couldn't connect with the GBIF data servers. Check your internet connection or try again later.")
+      } else {
+        warn_for_status(request)
+        taxon <- content(request)[[1]]$canonicalName
+      }
+    }
     taxon <- fixCase(taxon)
     uncertain <- regmatches(taxon, regexpr("[a|c]f+\\.", 
                                            taxon))
@@ -65,7 +77,9 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
     ident <- regmatches(taxon, regexpr("\\s+sp\\.+\\w*", 
                                        taxon))
     if (length(ident) != 0L) {
-      taxon <- unlist(strsplit(taxon, " "))[1]
+      split.name <- unlist(strsplit(taxon, " "))
+      taxon <- split.name[1]
+      infra <- split.name[2]
     }
     found <- length(with(all.taxa, {
       which(search.str == taxon)
@@ -97,6 +111,7 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
         notes <- c(notes, "check +1 accepted")
       }
       res[index, "notes"] <- paste(notes, collapse = "|")
+      if (length(ident) != 0L) res[index, "search.str"] <- paste(res[index, "search.str"], infra)
       next
     }
     synonym <- all.taxa[with(all.taxa, {
@@ -139,6 +154,7 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
         }
       }
       res[index, "notes"] <- paste(notes, collapse = "|")
+      if (length(ident) != 0L) res[index, "search.str"] <- paste(res[index, "search.str"], infra)
       next
     }
     
@@ -162,6 +178,7 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
     }
     
     res[index, "notes"] <- paste(notes, collapse = "|")
+    if (length(ident) != 0L) res[index, "search.str"] <- paste(taxa, infra)
   }
   if (is.null(drop)) {
     res <- data.frame(res, original.search, stringsAsFactors = FALSE)
@@ -171,24 +188,24 @@ get.taxa <- function (taxa, replace.synonyms = TRUE, suggest.names = TRUE,
                       stringsAsFactors = FALSE)
   }
   if (life.form) {
-    res <- merge(res, species.profiles[, c("id", "life.form")], 
-                 by = "id", all.x = TRUE, sort = FALSE)
+    res <- left_join(res, species.profiles[, c("id", "life.form")], 
+                     by = "id")
   }
   if (habitat) {
-    res <- merge(res, species.profiles[, c("id", "habitat")], 
-                 by = "id", all.x = TRUE, sort = FALSE)
+    res <- left_join(res, species.profiles[, c("id", "habitat")], 
+                     by = "id")
   }
   if (vernacular) {
-    res <- merge(res, vernacular.names[, c("id", "vernacular.name", 
-                                           "locality")], by = "id", all.x = TRUE, sort = FALSE)
+    res <- left_join(res, vernacular.names[, c("id", "vernacular.name")],
+                     by = "id")  
   }
   if (states) {
-    res <- merge(res, distribution[, c("id", "occurrence")], 
-                 by = "id", all.x = TRUE, sort = FALSE)
+    res <- left_join(res, distribution[, c("id", "occurrence")], 
+                     by = "id")
   }
   if (establishment) {
-    res <- merge(res, distribution[, c("id", "establishment")], 
-                 by = "id", all.x = TRUE, sort = FALSE)
+    res <- left_join(res, distribution[, c("id", "establishment")], 
+                     by = "id")
   }
   res
 }
\ No newline at end of file
